@@ -71,7 +71,14 @@ static void use_gmt_cb(GtkWidget *w, gpointer data)
 static void gmt_offset_cb(GtkObject *adj, gpointer data)
 {
 	AppData *ad = data;
-	ad->p_gmt_offset = (gint)GTK_ADJUSTMENT(adj)->value;
+	if (GTK_IS_ADJUSTMENT(adj))
+		{
+		ad->p_gmt_offset = (gint)GTK_ADJUSTMENT(adj)->value;
+		}
+	else
+		{
+		ad->p_gmt_offset = (gint)GTK_ADJUSTMENT(GTK_SPIN_BUTTON(adj)->adjustment)->value;
+		}
 	gnome_property_box_changed(GNOME_PROPERTY_BOX(ad->propwindow));
 } 
 
@@ -85,7 +92,14 @@ static void always_blink_cb(GtkWidget *w, gpointer data)
 static void mail_max_cb(GtkObject *adj, gpointer data)
 {
 	AppData *ad = data;
-	ad->p_mail_max = (gint)GTK_ADJUSTMENT(adj)->value;
+	if (GTK_IS_ADJUSTMENT(adj))
+		{
+		ad->p_mail_max = (gint)GTK_ADJUSTMENT(adj)->value;
+		}
+	else
+		{
+		ad->p_mail_max = (gint)GTK_ADJUSTMENT(GTK_SPIN_BUTTON(adj)->adjustment)->value;
+		}
 	gnome_property_box_changed(GNOME_PROPERTY_BOX(ad->propwindow));
 }
 
@@ -243,6 +257,7 @@ void property_show(AppletWidget *applet, gpointer data)
 	GtkWidget *button;
 	GtkObject *adj;
 	GtkWidget *spin;
+	GtkWidget *scrolled;
 	GtkWidget *theme_clist;
 	gchar *theme_title[] = { "Themes:", };
 
@@ -266,7 +281,7 @@ void property_show(AppletWidget *applet, gpointer data)
 	vbox = gtk_vbox_new(0, TRUE);
 
 	frame = gtk_frame_new(_("Clock"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -294,11 +309,12 @@ void property_show(AppletWidget *applet, gpointer data)
 	spin = gtk_spin_button_new( GTK_ADJUSTMENT(adj), 1, 0 );
 	gtk_box_pack_start( GTK_BOX(hbox), spin, FALSE, FALSE, 5);
 	gtk_signal_connect( GTK_OBJECT(adj),"value_changed",GTK_SIGNAL_FUNC(gmt_offset_cb), ad);
+	gtk_signal_connect( GTK_OBJECT(spin),"changed",GTK_SIGNAL_FUNC(gmt_offset_cb), ad);
 	gtk_spin_button_set_update_policy( GTK_SPIN_BUTTON(spin),GTK_UPDATE_ALWAYS );
 	gtk_widget_show(spin);
 
 	frame = gtk_frame_new(_("Mail"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -362,6 +378,7 @@ void property_show(AppletWidget *applet, gpointer data)
 	gtk_widget_set_usize(spin, 100, -1);
 	gtk_box_pack_start( GTK_BOX(hbox), spin, FALSE, FALSE, 5);
 	gtk_signal_connect( GTK_OBJECT(adj),"value_changed",GTK_SIGNAL_FUNC(mail_max_cb), ad);
+	gtk_signal_connect( GTK_OBJECT(spin),"changed",GTK_SIGNAL_FUNC(mail_max_cb), ad);
 	gtk_spin_button_set_update_policy( GTK_SPIN_BUTTON(spin),GTK_UPDATE_ALWAYS );
 	gtk_widget_show(spin);
 
@@ -372,10 +389,10 @@ void property_show(AppletWidget *applet, gpointer data)
 	/* theme tab */
 
 	frame = gtk_frame_new(NULL);
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
 
 	vbox = gtk_vbox_new(0, TRUE);
-	gtk_container_border_width (GTK_CONTAINER (vbox), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 	gtk_widget_show(vbox);
 
@@ -396,12 +413,17 @@ void property_show(AppletWidget *applet, gpointer data)
 	gtk_box_pack_start( GTK_BOX(hbox),ad->theme_entry , TRUE, TRUE, 5);
 	gtk_widget_show(ad->theme_entry);
 
+	scrolled = gtk_scrolled_window_new(NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
+				GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
+	gtk_box_pack_start(GTK_BOX(vbox), scrolled, TRUE, TRUE, 0);
+	gtk_widget_show(scrolled);
+
 	/* theme list */
 	theme_clist=gtk_clist_new_with_titles (1, theme_title);
-	gtk_clist_set_policy (GTK_CLIST (theme_clist), GTK_POLICY_ALWAYS, GTK_POLICY_AUTOMATIC); 
 	gtk_clist_column_titles_passive (GTK_CLIST (theme_clist)); 
 	gtk_signal_connect (GTK_OBJECT (theme_clist), "select_row",(GtkSignalFunc) theme_selected_cb, ad);
-	gtk_box_pack_start (GTK_BOX (vbox), theme_clist, TRUE, TRUE, 0);
+	gtk_container_add (GTK_CONTAINER (scrolled), theme_clist);
 	gtk_widget_show (theme_clist);
 
 	populate_theme_list(theme_clist);
