@@ -14,10 +14,11 @@
 #include <string.h>
 #include <config.h>
 #include <gnome.h>
-#include "applet-lib.h"
-#include "applet-widget.h"
+#include <applet-widget.h>
 #include <gdk_imlib.h>
 
+#include "mailcheck.h"
+
 #define WIDGET_HEIGHT 48
 
 GtkWidget *applet = NULL;
@@ -38,6 +39,10 @@ struct _MailCheck {
 	/* Does the user have unread mail? */
 	int unreadmail;
 
+  guint update_freq;
+
+  char *cmd;
+
 	/* This holds either the drawing area or the label */
 	GtkWidget *bin;
 
@@ -76,6 +81,8 @@ struct _MailCheck {
 
 	/* The property window */
 	GtkWidget *property_window;
+  GtkWidget *spin, *cmd_entry;
+  gboolean anim_changed;
 
 	char *mailcheck_text_only;
 
@@ -183,6 +190,16 @@ mail_check_timeout (gpointer data)
 {
 	MailCheck *mc = data;
 
+  if(mc->cmd) {
+    /* if we have to execute a command before checking for mail, we
+       remove the mail-check timeout and re-add it after the command
+       returns, just in case the execution takes too long. */
+    gtk_timeout_remove(mc->mail_timeout);
+    if(system(mc->cmd) == 127)
+      g_warning("Couldn't execute command");
+    mc->mail_timeout = gtk_timeout_add(mc->update_freq, mail_check_timeout, mc);
+  }
+                                      
 	check_mail_file_status (mc);
 
 	switch (mc->report_mail_mode){
@@ -260,6 +277,9 @@ mailcheck_destroy (GtkWidget *widget, gpointer data)
 	if (mc->property_window)
 		close_callback (NULL, mc);
 
+  if(mc->cmd)
+    g_free(mc->cmd);
+
 	gtk_timeout_remove (mc->mail_timeout);
 }
 
@@ -281,7 +301,7 @@ create_mail_widgets (MailCheck *mc)
 	gtk_widget_show (mc->bin);
 	check_mail_file_status (mc);
 	
-	mc->mail_timeout = gtk_timeout_add (10000, mail_check_timeout, mc);
+	mc->mail_timeout = gtk_timeout_add (mc->update_freq, mail_check_timeout, mc);
 
 	/* The drawing area */
 	gtk_widget_push_visual (gdk_imlib_get_visual ());
@@ -317,11 +337,19 @@ static void
 set_selection (GtkWidget *widget, gpointer data)
 {
 	MailCheck *mc = gtk_object_get_user_data(GTK_OBJECT(widget));
-	mc->selected_pixmap_name = data;
+  mc->selected_pixmap_name = data;
+  mc->anim_changed = TRUE;
 
 	gnome_property_box_changed (GNOME_PROPERTY_BOX (mc->property_window));
 }
 
+static void
+property_box_changed(GtkWidget *widget, gpointer data) {
+  MailCheck *mc = data;
+
+  gnome_property_box_changed (GNOME_PROPERTY_BOX (mc->property_window));
+}
+
 static void
 free_str (GtkWidget *widget, void *data)
 {
@@ -381,7 +409,6 @@ mailcheck_get_animation_menu (MailCheck *mc)
 
 			if (!mc->selected_pixmap_name)
 				mc->selected_pixmap_name = s;
-			printf ("%s, %s\n", basename, e->d_name);
 			if (basename && strcmp (basename, e->d_name) == 0)
 				select_item = i;
 			s = g_strdup (e->d_name);
@@ -408,10 +435,8 @@ close_callback (GtkWidget *widget, gpointer data)
 }
 
 static void
-load_new_pixmap_callback (GtkWidget *widget, gint button_num, gpointer data)
+load_new_pixmap (MailCheck *mc)
 {
-	MailCheck *mc = data;
-
 	gtk_widget_hide (mc->containee);
 	gtk_container_remove (GTK_CONTAINER (mc->bin), mc->containee);
 	
@@ -438,41 +463,96 @@ load_new_pixmap_callback (GtkWidget *widget, gint button_num, gpointer data)
 	gtk_widget_show (mc->containee);
 }
 
+static void
+apply_properties_callback (GtkWidget *widget, gint button_num, gpointer data) {
+  MailCheck *mc = (MailCheck *)data;
+
+  mc->update_freq = (guint)(gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(mc->spin))*1000);
+  gtk_timeout_remove(mc->mail_timeout);
+  mc->mail_timeout = gtk_timeout_add(mc->update_freq, mail_check_timeout, mc);
+
+  if(mc->cmd) {
+    g_free(mc->cmd);
+    mc->cmd = NULL;
+  }
+
+  if(strlen(gtk_entry_get_text(GTK_ENTRY(mc->cmd_entry))) > 0)
+    mc->cmd = g_strdup(gtk_entry_get_text(GTK_ENTRY(mc->cmd_entry)));
+
+  if(mc->anim_changed)
+    load_new_pixmap(mc);
+
+  mc->anim_changed = FALSE;
+}
+      
 static GtkWidget *
-mailcheck_notification_frame (MailCheck *mc)
+mailcheck_properties_page (MailCheck *mc)
 {
-	GtkWidget *f, *vbox, *hbox, *l;
-
-	f = gtk_frame_new (_("Notification"));
-	gtk_widget_show (f);
-	gtk_container_border_width (GTK_CONTAINER (f), 5);
-
-	/* If a lot of label/optionmenu pairs are added to the dialog,
-	 * you should use a GtkTable to keep stuff nicely aligned.
-	 */
+	GtkWidget *freq, *vbox, *hbox, *l, *entry;
+  GtkObject *freq_a;
 	
-	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox), 6);
-	gtk_container_add (GTK_CONTAINER (f), vbox);
+	vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
 	gtk_widget_show (vbox);
 
+	hbox = gtk_hbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+	gtk_widget_show (hbox);  
+
+  l = gtk_label_new(_("Execute"));
+  gtk_widget_show(l);
+	gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);
+
+  mc->cmd_entry = gtk_entry_new();
+  if(mc->cmd)
+    gtk_entry_set_text(GTK_ENTRY(mc->cmd_entry), mc->cmd);
+  gtk_signal_connect(GTK_OBJECT(mc->cmd_entry), "changed",
+                     GTK_SIGNAL_FUNC(property_box_changed), mc);
+  gtk_widget_show(mc->cmd_entry);
+	gtk_box_pack_start (GTK_BOX (hbox), mc->cmd_entry, FALSE, FALSE, 0);
+
+  l = gtk_label_new(_("before each update"));
+  gtk_widget_show(l);
+	gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);
+
 	hbox = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show (hbox);
 
+	l = gtk_label_new (_("Check for mail every"));
+  gtk_widget_show(l);
+	gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);
+
+	freq_a = gtk_adjustment_new((float)mc->update_freq/1000, 0.1, 3600, 0.1, 5, 5);
+	mc->spin  = gtk_spin_button_new (GTK_ADJUSTMENT (freq_a), 0.1, 1);
+  gtk_signal_connect(GTK_OBJECT(freq_a), "value_changed",
+                     GTK_SIGNAL_FUNC(property_box_changed), mc);
+  gtk_signal_connect(GTK_OBJECT(mc->spin), "changed",
+                     GTK_SIGNAL_FUNC(property_box_changed), mc);
+	gtk_box_pack_start (GTK_BOX (hbox), mc->spin,  FALSE, FALSE, 0);
+	gtk_widget_show(mc->spin);
+
+	l = gtk_label_new (_("s"));
+  gtk_widget_show(l);
+	gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);
+
+	hbox = gtk_hbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+	gtk_widget_show (hbox);  
+
 	l = gtk_label_new (_("Select animation"));
 	gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
 	gtk_widget_show (l);
 	gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), mailcheck_get_animation_menu (mc), FALSE, FALSE, 0);
 
-	return f;
+	return vbox;
 }
 
 static void
 mailcheck_properties (AppletWidget *applet, gpointer data)
 {
-	GtkWidget *f;
+	GtkWidget *p;
 
 	MailCheck *mc = data;
 
@@ -485,20 +565,19 @@ mailcheck_properties (AppletWidget *applet, gpointer data)
 	gtk_window_set_title (GTK_WINDOW (mc->property_window),
 			      _("Mail check properties"));
 
-	f = mailcheck_notification_frame (mc);
+	p = mailcheck_properties_page (mc);
 
 	gnome_property_box_append_page (GNOME_PROPERTY_BOX(mc->property_window),
-					f, gtk_label_new (_("Mail check")));
+					p, gtk_label_new (_("Mail check")));
 
 	gtk_signal_connect (GTK_OBJECT (mc->property_window), "apply",
-			    GTK_SIGNAL_FUNC(load_new_pixmap_callback), mc);
+			    GTK_SIGNAL_FUNC(apply_properties_callback), mc);
 	gtk_signal_connect (GTK_OBJECT (mc->property_window), "destroy",
 			    GTK_SIGNAL_FUNC(close_callback), mc);
 
 	gtk_widget_show (mc->property_window);
 }
 
-
 static gint
 applet_save_session(GtkWidget *w,
 		    const char *privcfgpath,
@@ -509,7 +588,10 @@ applet_save_session(GtkWidget *w,
 
 	gnome_config_push_prefix(privcfgpath);
 	gnome_config_set_string("mail/animation_file",
-				mc->animation_file?mc->animation_file:"");
+                          mc->animation_file?mc->animation_file:"");
+  gnome_config_set_int("mail/update_frequency", mc->update_freq);
+  gnome_config_set_string("mail/exec_command",
+                          mc->cmd?mc->cmd:"");
 	gnome_config_pop_prefix();
 
 	gnome_config_sync();
@@ -522,7 +604,10 @@ static void
 mailcheck_about(AppletWidget *a_widget, gpointer a_data)
 {
 	GtkWidget *about = NULL;
-	gchar     *authors [] = { "Miguel de Icaza (miguel@kernel.org)", NULL };
+	static const gchar     *authors [] =
+	{ "Miguel de Icaza <miguel@kernel.org>",
+	  "Jaka Mocnik <jaka.mocnik@kiss.uni-lj.si>",
+	  NULL };
 	
 	about = gnome_about_new ( _("Mail check Applet"), "1.0",
 				    _("(c) 1998 the Free Software Foundation"),
@@ -533,7 +618,7 @@ mailcheck_about(AppletWidget *a_widget, gpointer a_data)
 }
 
 GtkWidget *
-make_mailcheck_applet(const gchar *param)
+make_mailcheck_applet(const gchar *goad_id)
 {
 	GtkWidget *mailcheck;
 	MailCheck *mc;
@@ -544,6 +629,9 @@ make_mailcheck_applet(const gchar *param)
 	mc->animation_tag = -1;
 	mc->animation_file = NULL;
 	mc->property_window = NULL;
+  mc->anim_changed = FALSE;
+
+  mc->cmd = NULL;
 
 	/*initial state*/
 	mc->report_mail_mode = REPORT_MAIL_USE_ANIMATION;
@@ -560,7 +648,7 @@ make_mailcheck_applet(const gchar *param)
 		}
 	}
 
-	applet = applet_widget_new_with_param(param);
+	applet = applet_widget_new(goad_id);
 	if (!applet)
 		g_error(_("Can't create applet!\n"));
 
@@ -570,6 +658,17 @@ make_mailcheck_applet(const gchar *param)
 			       "mail/animation_file=",emailfile,NULL);
 	mc->animation_file = gnome_config_get_string(query);
 	g_free(query);
+
+  query = g_copy_strings(APPLET_WIDGET(applet)->privcfgpath,
+                         "mail/update_frequency=2000", NULL);
+  mc->update_freq = gnome_config_get_int(query);
+  g_free(query);
+
+  query = g_copy_strings(APPLET_WIDGET(applet)->privcfgpath,
+                         "mail/exec_command", NULL);
+  mc->cmd = gnome_config_get_string(query);
+  g_free(query);
+
 	if(emailfile) g_free(emailfile);
 
 	mc->mailcheck_text_only = _("Text only");
