@@ -125,37 +125,34 @@ XmImageInfo *load_image(GtkWidget *html_widget, gchar *ref);
 /* Menu and toolbar structures */
 
 GnomeUIInfo filemenu[] = {
+	{ GNOME_APP_UI_ITEM, N_("_New window"), N_("Open new browser window"), new_window_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 'n', GDK_CONTROL_MASK, NULL },
+	 
 	{GNOME_APP_UI_ITEM, 
-	 N_("New window"), N_("Open new browser window"),
-         new_window_cb, NULL, NULL, 
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
-	 0, 0, NULL},
-	{GNOME_APP_UI_ITEM, 
-	 N_("Add Bookmark"), N_("Add bookmark"),
+	 N_("_Add Bookmark"), N_("Add bookmark"),
          bookmark_cb, NULL, NULL, 
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE,
 	 0, 0, NULL},
+
+	{ GNOME_APP_UI_ITEM, N_("P_references..."), N_("Preferences"), config_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF, 0, 0, NULL },
+	 
 	{GNOME_APP_UI_ITEM, 
-	 N_("Configure"), N_("Configure"),
-         config_cb, NULL, NULL, 
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP,
-	 0, 0, NULL},
-	{GNOME_APP_UI_ITEM, 
-	 N_("Close"), N_("Close window"),
+	 N_("_Close"), N_("Close window"),
          close_cb, NULL, NULL, 
-	 GNOME_APP_PIXMAP_NONE, NULL,
-	 0, 0, NULL},
+	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE,
+	 'w', GDK_CONTROL_MASK, NULL},
 	{GNOME_APP_UI_ITEM, 
-	 N_("Exit"), N_("Exit all windows"),
+	 N_("E_xit"), N_("Exit all windows"),
          quit_cb, NULL, NULL, 
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT,
-	 0, 0, NULL},
+	 'x', GDK_CONTROL_MASK, NULL},
 	GNOMEUIINFO_END
 };
 
 GnomeUIInfo helpmenu[] = {
     {GNOME_APP_UI_ITEM, 
-     N_("About"), N_("Info about this program"),
+     N_("_About"), N_("Info about this program"),
      about_cb, NULL, NULL, 
      GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
      0, 0, NULL},
@@ -166,12 +163,12 @@ GnomeUIInfo helpmenu[] = {
  
 GnomeUIInfo windowmenu[] = {
 	{GNOME_APP_UI_ITEM, 
-	 N_("History"), N_("Show History Window"),
+	 N_("_History"), N_("Show History Window"),
          ghelpShowHistory, NULL, NULL, 
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{GNOME_APP_UI_ITEM, 
-	 N_("Bookmarks"), N_("Show Bookmarks Window"),
+	 N_("_Bookmarks"), N_("Show Bookmarks Window"),
          ghelpShowBookmarks, NULL, NULL, 
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -179,9 +176,9 @@ GnomeUIInfo windowmenu[] = {
 };
 
 GnomeUIInfo mainmenu[] = {
-    GNOMEUIINFO_SUBTREE(N_("File"), filemenu),
-    GNOMEUIINFO_SUBTREE(N_("Window"), windowmenu),
-    GNOMEUIINFO_SUBTREE(N_("Help"), helpmenu),
+    GNOMEUIINFO_SUBTREE(N_("_File"), filemenu),
+    GNOMEUIINFO_SUBTREE(N_("_Window"), windowmenu),
+    GNOMEUIINFO_SUBTREE(N_("_Help"), helpmenu),
     GNOMEUIINFO_END
 };
 
@@ -600,12 +597,6 @@ static void init_accel(HelpWindow win)
 	 GTK_RUN_FIRST,
 	 gtk_marshal_NONE__NONE,
 	 GTK_TYPE_NONE, 0);
-      grab_focus_signal = gtk_object_class_user_signal_new
-	(GTK_OBJECT(win->entryBox)->klass,
-	 "grab_focus",
-	 GTK_RUN_FIRST,
-	 gtk_marshal_NONE__NONE,
-	 GTK_TYPE_NONE, 0);
     }
     gtk_signal_connect(GTK_OBJECT(GTK_XMHTML (win->helpWidget)->html.vsb), 
 		       "page_up", 
@@ -613,10 +604,6 @@ static void init_accel(HelpWindow win)
     gtk_signal_connect(GTK_OBJECT(GTK_XMHTML (win->helpWidget)->html.vsb), 
 		       "page_down", 
 		       GTK_SIGNAL_FUNC(pageDown), win);
-    gtk_signal_connect(GTK_OBJECT(win->entryBox), 
-		       "grab_focus",
-		       GTK_SIGNAL_FUNC(gtk_widget_grab_focus), NULL);
-
     gtk_widget_add_accelerator(GTK_XMHTML (win->helpWidget)->html.vsb, 
 			       "page_up", accel_group, 
 			       'b', 0, 0);
