@@ -1,6 +1,9 @@
 #include <config.h>
 #include <string.h>
+#include <X11/X.h>
+#include <X11/Xlib.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 #include <gnome.h>
 
 #include <applet-widget.h>
@@ -112,7 +115,6 @@ typedef void (*AppletWidgetTooltipSignal) (GtkObject * object,
 					   int enabled,
 					   gpointer data);
 
-static GList *applet_widgets = NULL;
 static int applet_count = 0;
 
 static int do_multi = FALSE;
@@ -324,18 +326,18 @@ applet_servant_destroy(CustomAppletServant *servant)
   CORBA_exception_free(&ev);
 }
 
-static int
+static void
 applet_widget_destroy(GtkWidget *w, gpointer data)
 {
   AppletWidget *applet;
   CORBA_Environment ev;
 
-  g_return_val_if_fail(w != NULL,FALSE);
-  g_return_val_if_fail(IS_APPLET_WIDGET(w),FALSE);
+  g_return_if_fail(w != NULL);
+  g_return_if_fail(IS_APPLET_WIDGET(w));
 
   applet = APPLET_WIDGET(w);
   if(!applet->privcfgpath)
-    return FALSE;
+    return;
 
   g_free(applet->privcfgpath);
   g_free(applet->globcfgpath);
@@ -354,8 +356,6 @@ applet_widget_destroy(GtkWidget *w, gpointer data)
 
   if(die_on_last && applet_count == 0)
     applet_widget_gtk_main_quit();
-
-  return FALSE;
 }
 
 void
@@ -703,54 +703,48 @@ applet_widget_get_applet_count()
 	return applet_count;
 }
 
-/*button press event over the applet*/
 static int
-applet_bevent(GtkWidget *widget, GdkEventButton *bevent, GtkWidget *appw)
+applet_event(GtkWidget *w,GdkEvent *event,GtkPlug *aw)
 {
-	GtkWidget *w;
-	CORBA_Environment ev;
-	int retval = FALSE;
-	
-	CORBA_exception_init(&ev);
-
-	if(GNOME_Panel__get_in_drag(panel_client, &ev)) {
-		gtk_signal_emit_stop_by_name(GTK_OBJECT(widget),
-					     "button_press_event");
-		GNOME_PanelSpot_drag_stop(CD(appw)->pspot, &ev);
-		retval = TRUE;
-	} else if(bevent->button == 2) {
-		gtk_signal_emit_stop_by_name(GTK_OBJECT(widget),
-					     "button_press_event");
-		if((w = gtk_grab_get_current()))
-			gtk_grab_remove(w);
-		gdk_keyboard_ungrab(GDK_CURRENT_TIME);
-		gdk_pointer_ungrab(GDK_CURRENT_TIME);
-		gdk_flush();
-		GNOME_PanelSpot_drag_start(CD(appw)->pspot, &ev);
-		retval = TRUE;
-	} else if(bevent->button == 3) {
-		gtk_signal_emit_stop_by_name(GTK_OBJECT(widget),
-					     "button_press_event");
-		if((w = gtk_grab_get_current()))
-			gtk_grab_remove(w);
+	GdkEventButton *bevent = (GdkEventButton *)event;
+	if(event->type == GDK_BUTTON_PRESS && 
+	   (bevent->button == 3 || bevent->button == 2)) {
+		XButtonEvent ev;
+		GtkWidget *wi;
+		if((wi = gtk_grab_get_current()))
+			gtk_grab_remove(wi);
 		gdk_pointer_ungrab(GDK_CURRENT_TIME);
 		gdk_keyboard_ungrab(GDK_CURRENT_TIME);
 		gdk_flush();
-		GNOME_PanelSpot_show_menu(CD(appw)->pspot, &ev);
-		retval = TRUE;
+		gtk_signal_emit_stop_by_name(GTK_OBJECT(w),
+					     "event");
+		ev.type = ButtonPress;
+		ev.send_event = True;
+		ev.display = GDK_DISPLAY();
+		ev.window = GDK_WINDOW_XWINDOW(aw->socket_window);
+		ev.subwindow = None;
+		ev.time = bevent->time;
+		ev.x = bevent->x;
+		ev.y = bevent->y;
+		ev.x_root = bevent->x_root;
+		ev.y_root = bevent->y_root;
+		ev.state = bevent->state;
+		ev.button = bevent->button;
+		ev.same_screen = True;
+		XSendEvent(GDK_DISPLAY(),
+			   GDK_WINDOW_XWINDOW(aw->socket_window),
+			   True,NoEventMask,(XEvent *)&ev);
+		return TRUE;
 	}
-
-	CORBA_exception_free(&ev);
-
-	return retval;
+	return FALSE;
 }
 
 static void
 bind_applet_events(GtkWidget *widget, gpointer data)
 {
 	if (!GTK_WIDGET_NO_WINDOW(widget)) {
-		gtk_signal_connect(GTK_OBJECT(widget), "button_press_event",
-				   (GtkSignalFunc) applet_bevent,
+		gtk_signal_connect(GTK_OBJECT(widget), "event",
+				   (GtkSignalFunc) applet_event,
 				   data);
 	}
 	
@@ -790,6 +784,9 @@ applet_widget_set_widget_tooltip(AppletWidget *applet,
 	g_return_if_fail(widget != NULL);
 	g_return_if_fail(GTK_IS_WIDGET(widget));
 
+	if(!applet_tooltips)
+		applet_tooltips = gtk_tooltips_new();
+
 	gtk_tooltips_set_tip (applet_tooltips,widget,text,NULL);
 }
 
@@ -834,6 +831,7 @@ applet_widget_init(const char *app_id,
 	CORBA_Environment ev;
 	CORBA_ORB orb;
 
+	/*this is not called for shlib applets so we set it to true here*/
 	die_on_last = TRUE;
 
 	gnome_client_disable_master_connection ();
@@ -844,8 +842,6 @@ applet_widget_init(const char *app_id,
 
 	CORBA_exception_free(&ev);
 
-	applet_tooltips = gtk_tooltips_new();
-
 	return ret;
 }
 
@@ -970,6 +966,9 @@ server_applet_set_tooltips_state(CustomAppletServant *servant,
 				 CORBA_boolean enabled,
 				 CORBA_Environment *ev)
 {
+	if(!applet_tooltips)
+		applet_tooltips = gtk_tooltips_new();
+
 	if(enabled)
 		gtk_tooltips_enable(applet_tooltips);
 	else
