@@ -22,23 +22,23 @@
 /* Used for all the packing and padding options */
 #define CONFIG_PADDING_SIZE 3
 
-extern GList *applets;
-extern GList *applets_last;
+extern GSList *applets;
+extern GSList *applets_last;
 extern int applet_count;
 extern GlobalConfig global_config;
 
 extern GtkTooltips *panel_tooltips;
 
-extern GList *panel_list;
+extern GSList *panel_list;
 
 static void
 properties_apply_callback(GtkWidget *widget, int page, gpointer data)
 {
 	Drawer       *drawer = data;
 	GtkWidget    *pixentry = gtk_object_get_data(GTK_OBJECT(widget),
-						      "pixmap");
+						     "pixmap");
 	GtkWidget    *tipentry = gtk_object_get_data(GTK_OBJECT(widget),
-						      "tooltip");
+						     "tooltip");
 	char         *s;
 
 	if (page != -1)
@@ -48,7 +48,7 @@ properties_apply_callback(GtkWidget *widget, int page, gpointer data)
 		g_free(drawer->pixmap);
 	if(drawer->tooltip)
 		g_free(drawer->tooltip);
-	s = gnome_pixmap_entry_get_filename(GNOME_PIXMAP_ENTRY(pixentry));
+	s = gnome_icon_entry_get_filename(GNOME_ICON_ENTRY(pixentry));
 	if(!s || !*s) {
 		drawer->pixmap =
 			gnome_unconditional_pixmap_file ("panel-drawer.png");
@@ -75,32 +75,31 @@ properties_apply_callback(GtkWidget *widget, int page, gpointer data)
 			      drawer->tooltip,NULL);
 }
 
-static int
+static void
 properties_close_callback(GtkWidget *widget, gpointer data)
 {
 	Drawer *drawer = data;
-	/*GtkWidget *pixentry = gtk_object_get_data(GTK_OBJECT(widget),"pixmap");
-	GtkWidget *gtkpixentry =
-		gnome_pixmap_entry_gtk_entry(GNOME_PIXMAP_ENTRY(pixentry));
-	GtkWidget *tipentry = gtk_object_get_data(GTK_OBJECT(widget),"tooltip");*/
 	gtk_object_set_data(GTK_OBJECT(drawer->button),
 			    DRAWER_PROPERTIES,NULL);
-	/*gtk_signal_disconnect_by_data(GTK_OBJECT(gtkpixentry),widget);
-	gtk_signal_disconnect_by_data(GTK_OBJECT(tipentry),widget);*/
-	return FALSE;
 }
 
 static void
-set_toggle_not (GtkWidget *widget, gpointer data)
+set_toggle (GtkWidget *widget, gpointer data)
 {
 	PerPanelConfig *ppc = gtk_object_get_user_data(GTK_OBJECT(widget));
 	int *the_toggle = data;
 
-	*the_toggle = !(GTK_TOGGLE_BUTTON(widget)->active);
+	*the_toggle = GTK_TOGGLE_BUTTON(widget)->active;
 	if (ppc->register_changes)
 		gnome_property_box_changed (GNOME_PROPERTY_BOX (ppc->config_window));
 }
 
+static void
+set_sensitive_toggle (GtkWidget *widget, GtkWidget *widget2)
+{
+	gtk_widget_set_sensitive(widget2,GTK_TOGGLE_BUTTON(widget)->active);
+}
+
 void
 add_drawer_properties_page(PerPanelConfig *ppc, Drawer *drawer)
 {
@@ -121,8 +120,8 @@ add_drawer_properties_page(PerPanelConfig *ppc, Drawer *drawer)
 			      drawer->tooltip, dialog);
 	gtk_object_set_data(GTK_OBJECT(dialog),"tooltip",w);
 	
-	w = create_pixmap_entry(table, "icon", 1, _("Icon"), drawer->pixmap,
-				dialog,64,64);
+	w = create_icon_entry(table, "icon", 1, _("Icon"), drawer->pixmap,
+			      dialog);
 	gtk_object_set_data(GTK_OBJECT(dialog),"pixmap",w);
 
 	f = gtk_frame_new(_("Applet appearance"));
@@ -134,22 +133,29 @@ add_drawer_properties_page(PerPanelConfig *ppc, Drawer *drawer)
 
 	f = gtk_frame_new(_("Drawer handle"));
 	box_in = gtk_vbox_new(FALSE,5);
-	button = gtk_check_button_new_with_label (_("Disable hidebutton"));
+	/*we store this in w for later use!, so don't use w as temp from now
+	  on*/
+	w = button = gtk_check_button_new_with_label (_("Enable hidebutton"));
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (!ppc->drawer_hidebutton)
+	if (ppc->drawer_hidebutton)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
-			    GTK_SIGNAL_FUNC (set_toggle_not),
+			    GTK_SIGNAL_FUNC (set_toggle),
 			    &ppc->drawer_hidebutton);
 	gtk_box_pack_start (GTK_BOX (box_in), button, TRUE, FALSE,
 			    CONFIG_PADDING_SIZE);
 
-	button = gtk_check_button_new_with_label (_("Disable hidebutton arrow"));
+	button = gtk_check_button_new_with_label (_("Enable hidebutton arrow"));
+	gtk_signal_connect (GTK_OBJECT (w), "toggled", 
+			    GTK_SIGNAL_FUNC (set_sensitive_toggle),
+			    button);
+	if (!ppc->drawer_hidebutton)
+		gtk_widget_set_sensitive(button,FALSE);
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (!ppc->drawer_hidebutton_pixmap)
+	if (ppc->drawer_hidebutton_pixmap)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
-			    GTK_SIGNAL_FUNC (set_toggle_not),
+			    GTK_SIGNAL_FUNC (set_toggle),
 			    &ppc->drawer_hidebutton_pixmap);
 	gtk_box_pack_start (GTK_BOX (box_in), button, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
@@ -194,7 +200,7 @@ drawer_click(GtkWidget *w, Drawer *drawer)
 	}
 }
 
-static int
+static void
 destroy_drawer(GtkWidget *widget, gpointer data)
 {
 	Drawer *drawer = data;
@@ -203,7 +209,6 @@ destroy_drawer(GtkWidget *widget, gpointer data)
 	if(prop_dialog)
 		gtk_widget_destroy(prop_dialog);
 	g_free(drawer);
-	return FALSE;
 }
 
 static int
@@ -334,22 +339,22 @@ button_size_alloc(GtkWidget *widget, GtkAllocation *alloc, Drawer *drawer)
 }
 
 void
-load_drawer_applet(char *params, char *pixmap, char *tooltip,
+load_drawer_applet(int mypanel, char *pixmap, char *tooltip,
 		   PanelWidget *panel, int pos)
 {
 	Drawer *drawer;
 	PanelOrientType orient = get_applet_orient(panel);
 
-	if(!params) {
+	if(mypanel < 0) {
 		drawer = create_empty_drawer_applet(tooltip,pixmap,orient);
 		if(drawer) panel_setup(drawer->drawer);
 	} else {
-		int i;
 		PanelData *dr_pd;
+		GSList *li;
 
-		sscanf(params,"%d",&i);
-		dr_pd = g_list_nth(panel_list,i)->data;
-		
+		li = g_slist_nth(panel_list,mypanel);
+		g_return_if_fail(li != NULL);
+		dr_pd = li->data;
 
 		drawer=create_drawer_applet(dr_pd->panel, tooltip,pixmap,
 					    orient);
