@@ -2,6 +2,7 @@
 #include <string.h>
 #include <glib.h>
 #include <fcntl.h>
+#include <dirent.h>
 
 #include "panel-include.h"
 
@@ -110,9 +111,9 @@ move_window(GtkWidget *widget, int x, int y)
 
 
 int
-string_is_in_list(GList *list,char *text)
+string_is_in_list(GSList *list,char *text)
 {
-	for(;list!=NULL;list=g_list_next(list))
+	for(;list!=NULL;list=g_slist_next(list))
 		if(strcmp(text,list->data)==0)
 			return TRUE;
 	return FALSE;
@@ -379,3 +380,286 @@ my_g_list_pop_first(GList *list)
 	g_list_free_1(list);
 	return r;
 }
+
+GSList *
+my_g_slist_pop_first(GSList *list)
+{
+	GSList *r;
+	
+	if(!list)
+		return NULL;
+       
+	r = list->next;
+	list->next = NULL;
+	g_slist_free_1(list);
+	return r;
+}
+
+/*following code shamelessly stolen from gtk*/
+static void
+rgb_to_hls (gdouble *r,
+	    gdouble *g,
+	    gdouble *b)
+{
+  gdouble min;
+  gdouble max;
+  gdouble red;
+  gdouble green;
+  gdouble blue;
+  gdouble h, l, s;
+  gdouble delta;
+
+  red = *r;
+  green = *g;
+  blue = *b;
+
+  if (red > green)
+    {
+      if (red > blue)
+	max = red;
+      else
+	max = blue;
+
+      if (green < blue)
+	min = green;
+      else
+	min = blue;
+    }
+  else
+    {
+      if (green > blue)
+	max = green;
+      else
+	max = blue;
+
+      if (red < blue)
+	min = red;
+      else
+	min = blue;
+    }
+
+  l = (max + min) / 2;
+  s = 0;
+  h = 0;
+
+  if (max != min)
+    {
+      if (l <= 0.5)
+	s = (max - min) / (max + min);
+      else
+	s = (max - min) / (2 - max - min);
+
+      delta = max -min;
+      if (red == max)
+	h = (green - blue) / delta;
+      else if (green == max)
+	h = 2 + (blue - red) / delta;
+      else if (blue == max)
+	h = 4 + (red - green) / delta;
+
+      h *= 60;
+      if (h < 0.0)
+	h += 360;
+    }
+
+  *r = h;
+  *g = l;
+  *b = s;
+}
+
+static void
+hls_to_rgb (gdouble *h,
+	    gdouble *l,
+	    gdouble *s)
+{
+  gdouble hue;
+  gdouble lightness;
+  gdouble saturation;
+  gdouble m1, m2;
+  gdouble r, g, b;
+
+  lightness = *l;
+  saturation = *s;
+
+  if (lightness <= 0.5)
+    m2 = lightness * (1 + saturation);
+  else
+    m2 = lightness + saturation - lightness * saturation;
+  m1 = 2 * lightness - m2;
+
+  if (saturation == 0)
+    {
+      *h = lightness;
+      *l = lightness;
+      *s = lightness;
+    }
+  else
+    {
+      hue = *h + 120;
+      while (hue > 360)
+	hue -= 360;
+      while (hue < 0)
+	hue += 360;
+
+      if (hue < 60)
+	r = m1 + (m2 - m1) * hue / 60;
+      else if (hue < 180)
+	r = m2;
+      else if (hue < 240)
+	r = m1 + (m2 - m1) * (240 - hue) / 60;
+      else
+	r = m1;
+
+      hue = *h;
+      while (hue > 360)
+	hue -= 360;
+      while (hue < 0)
+	hue += 360;
+
+      if (hue < 60)
+	g = m1 + (m2 - m1) * hue / 60;
+      else if (hue < 180)
+	g = m2;
+      else if (hue < 240)
+	g = m1 + (m2 - m1) * (240 - hue) / 60;
+      else
+	g = m1;
+
+      hue = *h - 120;
+      while (hue > 360)
+	hue -= 360;
+      while (hue < 0)
+	hue += 360;
+
+      if (hue < 60)
+	b = m1 + (m2 - m1) * hue / 60;
+      else if (hue < 180)
+	b = m2;
+      else if (hue < 240)
+	b = m1 + (m2 - m1) * (240 - hue) / 60;
+      else
+	b = m1;
+
+      *h = r;
+      *l = g;
+      *s = b;
+    }
+}
+
+static void
+gtk_style_shade (GdkColor *a,
+		 GdkColor *b,
+		 gdouble   k)
+{
+  gdouble red;
+  gdouble green;
+  gdouble blue;
+
+  red = (gdouble) a->red / 65535.0;
+  green = (gdouble) a->green / 65535.0;
+  blue = (gdouble) a->blue / 65535.0;
+
+  rgb_to_hls (&red, &green, &blue);
+
+  green *= k;
+  if (green > 1.0)
+    green = 1.0;
+  else if (green < 0.0)
+    green = 0.0;
+
+  blue *= k;
+  if (blue > 1.0)
+    blue = 1.0;
+  else if (blue < 0.0)
+    blue = 0.0;
+
+  hls_to_rgb (&red, &green, &blue);
+
+  b->red = red * 65535.0;
+  b->green = green * 65535.0;
+  b->blue = blue * 65535.0;
+}
+
+#define LIGHTNESS_MULT  1.3
+#define DARKNESS_MULT   0.7
+
+void
+set_frame_colors(PanelWidget *panel, GtkWidget *frame,
+		 GtkWidget *but1, GtkWidget *but2, GtkWidget *but3, GtkWidget *but4)
+{
+	if(panel->back_type == PANEL_BACK_COLOR) {
+		GtkStyle *ns;
+		int i;
+
+		ns = gtk_style_copy(GTK_WIDGET(panel)->style);
+		gtk_style_ref(ns);
+
+		ns->bg[GTK_STATE_NORMAL] =
+			panel->back_color;
+		gtk_style_shade (&panel->back_color,
+				 &ns->bg[GTK_STATE_PRELIGHT],1.5);
+		gtk_style_shade (&panel->back_color,
+				 &ns->bg[GTK_STATE_ACTIVE],0.8);
+		ns->bg[GTK_STATE_INSENSITIVE] = 
+			panel->back_color;
+
+		for (i = 0; i < 5; i++) {
+			gtk_style_shade (&ns->bg[i], &ns->light[i], LIGHTNESS_MULT);
+			gtk_style_shade (&ns->bg[i], &ns->dark[i], DARKNESS_MULT);
+
+			ns->mid[i].red = (ns->light[i].red + ns->dark[i].red) / 2;
+			ns->mid[i].green = (ns->light[i].green + ns->dark[i].green) / 2;
+			ns->mid[i].blue = (ns->light[i].blue + ns->dark[i].blue) / 2;
+		}
+		gtk_widget_set_style(frame, ns);
+		gtk_widget_set_style(but1, ns);
+		gtk_widget_set_style(but2, ns);
+		gtk_widget_set_style(but3, ns);
+		gtk_widget_set_style(but4, ns);
+		gtk_style_unref(ns);
+	} else {
+		GtkStyle *ns;
+
+		ns = gtk_rc_get_style(frame);
+		if(!ns) ns = gtk_style_new();
+
+		gtk_style_ref(ns);
+		gtk_widget_set_style(frame, ns);
+		gtk_widget_set_style(but1, ns);
+		gtk_widget_set_style(but2, ns);
+		gtk_widget_set_style(but3, ns);
+		gtk_widget_set_style(but4, ns);
+		gtk_style_unref(ns);
+	}
+}
+
+
+void
+remove_directory(char *dirname, int just_clean)
+{
+	DIR *dir;
+	struct dirent *dent;
+	char *oldcwd;
+
+	dir = opendir (dirname);
+	if(!dir) return;
+	oldcwd = g_get_current_dir();
+
+	chdir(dirname);
+	while((dent = readdir (dir)) != NULL) {
+		if(strcmp(dent->d_name,".")==0 ||
+		   strcmp(dent->d_name,"..")==0)
+			continue;
+		if(g_file_test(dent->d_name,G_FILE_TEST_ISDIR))
+			remove_directory(dent->d_name, FALSE);
+		else
+			unlink(dent->d_name);
+	}
+	closedir(dir);
+	chdir(oldcwd);
+
+	if(!just_clean)
+		rmdir(dirname);
+	g_free(oldcwd);
+}
+
