@@ -13,7 +13,7 @@
 #include "panel-util.h"
 #include "gdkextra.h"
 
-GList *panels=NULL; /*other panels we might want to move the applet to*/
+GSList *panels=NULL; /*other panels we might want to move the applet to*/
 
 /*define for some debug output*/
 /*#define DEBUG 1*/
@@ -263,7 +263,7 @@ panel_widget_class_init (PanelWidgetClass *class)
 static void
 remove_panel_from_forbidden(PanelWidget *panel, PanelWidget *r)
 {
-	GList *list;
+	GSList *list;
 	GtkWidget *parent_panel;
 	
 	g_return_if_fail(panel!=NULL);
@@ -277,7 +277,7 @@ remove_panel_from_forbidden(PanelWidget *panel, PanelWidget *r)
 	list = gtk_object_get_data(GTK_OBJECT(panel->master_widget),
 				   PANEL_APPLET_FORBIDDEN_PANELS);
 	if(list) {
-		list = g_list_remove(list,r);
+		list = g_slist_remove(list,r);
 		gtk_object_set_data(GTK_OBJECT(panel->master_widget),
 				    PANEL_APPLET_FORBIDDEN_PANELS,
 				    list);
@@ -290,7 +290,7 @@ remove_panel_from_forbidden(PanelWidget *panel, PanelWidget *r)
 static void
 add_panel_to_forbidden(PanelWidget *panel, PanelWidget *r)
 {
-	GList *list;
+	GSList *list;
 	GtkWidget *parent_panel;
 
 	g_return_if_fail(panel!=NULL);
@@ -303,8 +303,8 @@ add_panel_to_forbidden(PanelWidget *panel, PanelWidget *r)
 
 	list = gtk_object_get_data(GTK_OBJECT(panel->master_widget),
 				   PANEL_APPLET_FORBIDDEN_PANELS);
-	if(g_list_find(list,r)==NULL) {
-		list = g_list_prepend(list,r);
+	if(g_slist_find(list,r)==NULL) {
+		list = g_slist_prepend(list,r);
 
 		gtk_object_set_data(GTK_OBJECT(panel->master_widget),
 				    PANEL_APPLET_FORBIDDEN_PANELS,
@@ -423,19 +423,6 @@ get_applet_list_pos(PanelWidget *panel, int pos)
 	return NULL;
 }
 
-AppletData *
-get_applet_data_pos(PanelWidget *panel, int pos)
-{
-	GList *list;
-
-	g_return_val_if_fail(panel!=NULL,NULL);
-	g_return_val_if_fail(IS_PANEL_WIDGET(panel),NULL);
-	
-	if((list = get_applet_list_pos(panel,pos)))
-		return list->data;
-	return NULL;
-}
-
 /*tells us if an applet is "stuck" on the right side*/
 int
 panel_widget_is_applet_stuck(PanelWidget *panel, GtkWidget *applet)
@@ -1281,22 +1268,20 @@ panel_widget_realize(GtkWidget *w, gpointer data)
 	panel_widget_draw_all(panel);
 }
 
-static int
+static void
 panel_widget_destroy(GtkWidget *w, gpointer data)
 {
 	GdkImlibImage *im;
 
-	g_return_val_if_fail(w!=NULL,FALSE);
-	g_return_val_if_fail(IS_PANEL_WIDGET(w),FALSE);
+	g_return_if_fail(w!=NULL);
+	g_return_if_fail(IS_PANEL_WIDGET(w));
 
 	im = gtk_object_get_data(GTK_OBJECT(w),"gdk_image");
 	if(im) gdk_imlib_destroy_image (im);
 	gtk_object_set_data(GTK_OBJECT(w),"gdk_image",NULL);
 	
 	/*remove from panels list*/
-	panels = g_list_remove(panels,w);
-	
-	return FALSE;
+	panels = g_slist_remove(panels,w);
 }
 
 static int panel_widget_applet_event(GtkWidget *widget, GdkEvent *event, gpointer data);
@@ -1385,7 +1370,7 @@ panel_widget_init (PanelWidget *panel)
 			   GTK_SIGNAL_FUNC(panel_widget_event),
 			   NULL);
 
-	panels = g_list_append(panels,panel);
+	panels = g_slist_append(panels,panel);
 }
 
 GtkWidget *
@@ -1705,6 +1690,10 @@ panel_widget_nice_move(PanelWidget *panel, AppletData *ad, int pos)
 	gtk_widget_queue_resize(GTK_WIDGET(panel));
 }
 
+static int moving_timeout = -1;
+static int been_moved = FALSE;
+
+
 /*find the cursor position and move the applet to that position*/
 int
 panel_widget_applet_move_to_cursor(PanelWidget *panel)
@@ -1716,7 +1705,7 @@ panel_widget_applet_move_to_cursor(PanelWidget *panel)
 		int moveby;
 		int pos = panel->currently_dragged_applet->pos;
 		GtkWidget *applet;
-		GList *forb;
+		GSList *forb;
 
 		applet = panel->currently_dragged_applet->applet;
 		g_assert(GTK_IS_WIDGET(applet));
@@ -1724,16 +1713,16 @@ panel_widget_applet_move_to_cursor(PanelWidget *panel)
 					   PANEL_APPLET_FORBIDDEN_PANELS);
 
 		if(!panel_widget_is_cursor(panel,10)) {
-			GList *list;
+			GSList *list;
 			for(list=panels;
 			    list!=NULL;
-			    list=g_list_next(list)) {
+			    list=g_slist_next(list)) {
 			    	PanelWidget *new_panel =
 			    		PANEL_WIDGET(list->data);
 
 			    	if(panel != new_panel &&
 			    	   panel_widget_is_cursor(new_panel,10) &&
-				   (!g_list_find(forb,new_panel))) {
+				   (!g_slist_find(forb,new_panel))) {
 					pos = panel_widget_get_moveby(
 						new_panel,0);
 					if(pos<0)
@@ -1750,15 +1739,9 @@ panel_widget_applet_move_to_cursor(PanelWidget *panel)
 					_panel_widget_applet_drag_end(panel);
 					_panel_widget_applet_drag_start(
 						new_panel, applet);
-					panel_widget_applet_move_use_idle(
-						new_panel);
 			    	   	return FALSE;
 			    	}
 			}
-			/*FIXME: without this it's sometimes hard to get
-			  applets onto drawers, but it's an annoying
-			  behaviour*/
-			/*return TRUE;*/
 		}
 
 		if(pw_movement_type == PANEL_SWITCH_MOVE ||
@@ -1787,17 +1770,13 @@ move_timeout_handler(gpointer data)
 {
 	g_return_val_if_fail(data!=NULL,FALSE);
 	g_return_val_if_fail(IS_PANEL_WIDGET(data),FALSE);
-
-	return panel_widget_applet_move_to_cursor(PANEL_WIDGET(data));
-}
-
-void
-panel_widget_applet_move_use_idle(PanelWidget *panel)
-{
-	g_return_if_fail(panel!=NULL);
-	g_return_if_fail(IS_PANEL_WIDGET(panel));
-
-	gtk_timeout_add (30,move_timeout_handler,panel);
+	
+	if(been_moved)
+		panel_widget_applet_move_to_cursor(PANEL_WIDGET(data));
+	been_moved = FALSE;
+	moving_timeout = -1;
+	
+	return FALSE;
 }
 
 
@@ -1817,7 +1796,7 @@ panel_widget_applet_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 	panel = PANEL_WIDGET(widget->parent);
 
 	g_return_val_if_fail(panel!=NULL,TRUE);
-
+	
 	switch (event->type) {
 		case GDK_BUTTON_PRESS:
 			bevent = (GdkEventButton *) event;
@@ -1830,7 +1809,6 @@ panel_widget_applet_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 			if(bevent->button == 2) {
 				/* Start drag */
 				panel_widget_applet_drag_start(panel, widget);
-				panel_widget_applet_move_use_idle(panel);
 				return TRUE;
 			}
 
@@ -1843,7 +1821,16 @@ panel_widget_applet_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 			}
 
 			break;
-
+		case GDK_MOTION_NOTIFY:
+			if (panel->currently_dragged_applet) {
+				if(moving_timeout==-1) {
+					been_moved = FALSE;
+					panel_widget_applet_move_to_cursor(panel);
+					moving_timeout = gtk_timeout_add (30,move_timeout_handler,panel);
+				} else
+					been_moved = TRUE;
+			}
+			break;
 		default:
 			break;
 	}
@@ -1863,6 +1850,7 @@ panel_sub_event_handler(GtkWidget *widget, GdkEvent *event, gpointer data)
 		/*pass these to the parent!*/
 		case GDK_BUTTON_PRESS:
 		case GDK_BUTTON_RELEASE:
+		case GDK_MOTION_NOTIFY:
 			bevent = (GdkEventButton *)event;
 			if(bevent->button != 1 || panel_applet_in_drag)
 				return gtk_widget_event(data, event);
@@ -1900,13 +1888,14 @@ bind_applet_events(GtkWidget *widget, gpointer data)
 		gtk_container_foreach (GTK_CONTAINER (widget),
 				       bind_applet_events, data);
 }
-static int
+
+static void
 panel_widget_applet_destroy(GtkWidget *applet, gpointer data)
 {
 	AppletData *ad;
 
-	g_return_val_if_fail(applet!=NULL,FALSE);
-	g_return_val_if_fail(GTK_IS_WIDGET(applet),FALSE);
+	g_return_if_fail(applet!=NULL);
+	g_return_if_fail(GTK_IS_WIDGET(applet));
 
 	ad = gtk_object_get_data(GTK_OBJECT(applet), PANEL_APPLET_DATA);
 
@@ -1923,7 +1912,6 @@ panel_widget_applet_destroy(GtkWidget *applet, gpointer data)
 	}
 
 	g_free(ad);
-	return FALSE;
 }
 
 
@@ -2286,9 +2274,9 @@ panel_widget_change_global(int explicit_step,
 
 	/*change padding on all panels NOW*/
 	if(pw_applet_padding != applet_padding) {
-		GList *li;
+		GSList *li;
 		pw_applet_padding = applet_padding;
-		for(li=panels;li!=NULL;li=g_list_next(li))
+		for(li=panels;li!=NULL;li=g_slist_next(li))
 			gtk_widget_queue_resize(li->data);
 	}
 }
