@@ -109,7 +109,7 @@ update_config_back(PanelWidget *pw)
 	}
 }
 
-static int 
+static void
 config_destroy(GtkWidget *widget, gpointer data)
 {
 	PerPanelConfig *ppc = data;
@@ -118,8 +118,6 @@ config_destroy(GtkWidget *widget, gpointer data)
 	
 	g_free(ppc->back_pixmap);
 	g_free(ppc);
-
-	return FALSE;
 }
 
 static void
@@ -206,16 +204,22 @@ config_event(GtkWidget *widget,GdkEvent *event,GtkNotebook *nbook)
 }
 
 static void
-set_toggle_not (GtkWidget *widget, gpointer data)
+set_toggle (GtkWidget *widget, gpointer data)
 {
 	PerPanelConfig *ppc = gtk_object_get_user_data(GTK_OBJECT(widget));
 	int *the_toggle = data;
 
-	*the_toggle = !(GTK_TOGGLE_BUTTON(widget)->active);
+	*the_toggle = GTK_TOGGLE_BUTTON(widget)->active;
 	if (ppc->register_changes)
 		gnome_property_box_changed (GNOME_PROPERTY_BOX (ppc->config_window));
 }
 
+static void
+set_sensitive_toggle (GtkWidget *widget, GtkWidget *widget2)
+{
+	gtk_widget_set_sensitive(widget2,GTK_TOGGLE_BUTTON(widget)->active);
+}
+
 static void
 snapped_set_pos (GtkWidget *widget, gpointer data)
 {
@@ -231,15 +235,15 @@ snapped_set_pos (GtkWidget *widget, gpointer data)
 }
 
 static void
-snapped_set_mode (GtkWidget *widget, gpointer data)
+snapped_set_auto_hide (GtkWidget *widget, gpointer data)
 {
-	SnappedMode mode = (SnappedMode) data;
 	PerPanelConfig *ppc = gtk_object_get_user_data(GTK_OBJECT(widget));
 
-	if(!(GTK_TOGGLE_BUTTON(widget)->active))
-		return;
+	if(GTK_TOGGLE_BUTTON(widget)->active)
+		ppc->snapped_mode = SNAPPED_AUTO_HIDE;
+	else
+		ppc->snapped_mode = SNAPPED_EXPLICIT_HIDE;
 	
-	ppc->snapped_mode = mode;
 	if (ppc->register_changes)
 		gnome_property_box_changed (GNOME_PROPERTY_BOX (ppc->config_window));
 }
@@ -252,7 +256,12 @@ snapped_notebook_page(PerPanelConfig *ppc)
 	GtkWidget *button;
 	GtkWidget *box;
 	GtkWidget *hbox;
+	GtkWidget *vbox;
         GtkWidget *table;
+        GtkWidget *w;
+
+	/* main vbox */
+	vbox = gtk_vbox_new (FALSE, 0);
 	
 	/* main hbox */
 	hbox = gtk_hbox_new (FALSE, CONFIG_PADDING_SIZE);
@@ -333,7 +342,7 @@ snapped_notebook_page(PerPanelConfig *ppc)
 	}
 
 	/* Auto-hide/stayput frame */
-	frame = gtk_frame_new (_("Minimize Options"));
+	frame = gtk_frame_new (_("Minimize options"));
 	gtk_container_set_border_width(GTK_CONTAINER (frame), CONFIG_PADDING_SIZE);
 	gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
@@ -343,53 +352,47 @@ snapped_notebook_page(PerPanelConfig *ppc)
 	gtk_container_set_border_width(GTK_CONTAINER (box), CONFIG_PADDING_SIZE);
 	gtk_container_add (GTK_CONTAINER (frame), box);
 	
-	/* Stay Put */
-	button = gtk_radio_button_new_with_label (NULL, _("Explicitly Hide"));
-	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (ppc->snapped_mode == SNAPPED_EXPLICIT_HIDE)
-		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
-			    GTK_SIGNAL_FUNC (snapped_set_mode), 
-			    (gpointer)SNAPPED_EXPLICIT_HIDE);
-	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,
-			    CONFIG_PADDING_SIZE);
-	
 	/* Auto-hide */
-	button = gtk_radio_button_new_with_label (
-			  gtk_radio_button_group (GTK_RADIO_BUTTON (button)),
-			  _("Auto Hide"));
+	button = gtk_check_button_new_with_label(_("Auto hide"));
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
 	if (ppc->snapped_mode == SNAPPED_AUTO_HIDE)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
-			    GTK_SIGNAL_FUNC (snapped_set_mode), 
-			    (gpointer)SNAPPED_AUTO_HIDE);
+			    GTK_SIGNAL_FUNC (snapped_set_auto_hide), 
+			    NULL);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
-	/* Hidebuttons disable */
-	button = gtk_check_button_new_with_label (_("Disable hidebuttons"));
+	/* Hidebuttons enable */
+	w = button = gtk_check_button_new_with_label (_("Enable hidebuttons"));
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (!ppc->snapped_hidebuttons)
+	if (ppc->snapped_hidebuttons)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
-			    GTK_SIGNAL_FUNC (set_toggle_not),
+			    GTK_SIGNAL_FUNC (set_toggle),
 			    &ppc->snapped_hidebuttons);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
-	/* Arrow disable */
-	button = gtk_check_button_new_with_label (_("Disable hidebutton arrows"));
+	/* Arrow enable */
+	button = gtk_check_button_new_with_label (_("Enable hidebutton arrows"));
+	gtk_signal_connect (GTK_OBJECT (w), "toggled", 
+			    GTK_SIGNAL_FUNC (set_sensitive_toggle),
+			    button);
+	if (!ppc->snapped_hidebuttons)
+		gtk_widget_set_sensitive(button,FALSE);
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (!ppc->snapped_hidebutton_pixmaps)
+	if (ppc->snapped_hidebutton_pixmaps)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
-			    GTK_SIGNAL_FUNC (set_toggle_not),
+			    GTK_SIGNAL_FUNC (set_toggle),
 			    &ppc->snapped_hidebutton_pixmaps);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
-	return (hbox);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+
+	return (vbox);
 }
 
 static void
@@ -426,6 +429,7 @@ corner_notebook_page(PerPanelConfig *ppc)
 {
 	GtkWidget *frame;
 	GtkWidget *button;
+	GtkWidget *w;
 	GtkWidget *box;
 	GtkWidget *hbox;
 	GtkWidget *vbox;
@@ -449,7 +453,7 @@ corner_notebook_page(PerPanelConfig *ppc)
 	gtk_container_add (GTK_CONTAINER (frame), table);
 	
 	/* North East Position */
-	ppc->t_button = gtk_radio_button_new_with_label (NULL, _("North East"));
+	ppc->t_button = gtk_radio_button_new_with_label (NULL, _("North east"));
 	gtk_object_set_user_data(GTK_OBJECT(ppc->t_button),ppc);
 	gtk_signal_connect (GTK_OBJECT (ppc->t_button), "toggled", 
 			    GTK_SIGNAL_FUNC (corner_set_pos), 
@@ -460,7 +464,7 @@ corner_notebook_page(PerPanelConfig *ppc)
 	/* Bottom Position */
 	ppc->b_button = gtk_radio_button_new_with_label (
 		 gtk_radio_button_group (GTK_RADIO_BUTTON (ppc->t_button)),
-		 _("South West"));
+		 _("South west"));
 	gtk_object_set_user_data(GTK_OBJECT(ppc->b_button),ppc);
 	gtk_signal_connect (GTK_OBJECT (ppc->b_button), "toggled", 
 			    GTK_SIGNAL_FUNC (corner_set_pos), 
@@ -471,7 +475,7 @@ corner_notebook_page(PerPanelConfig *ppc)
 	/* North West Position */
 	ppc->l_button = gtk_radio_button_new_with_label (
 		  gtk_radio_button_group (GTK_RADIO_BUTTON (ppc->t_button)),
-		  _("North West"));
+		  _("North west"));
 	gtk_object_set_user_data(GTK_OBJECT(ppc->l_button),ppc);
 	gtk_signal_connect (GTK_OBJECT (ppc->l_button), "toggled", 
 			    GTK_SIGNAL_FUNC (corner_set_pos), 
@@ -482,7 +486,7 @@ corner_notebook_page(PerPanelConfig *ppc)
 	/* South East Position */
 	ppc->r_button = gtk_radio_button_new_with_label (
 		 gtk_radio_button_group (GTK_RADIO_BUTTON (ppc->t_button)),
-		 _("South East"));
+		 _("South east"));
 	gtk_object_set_user_data(GTK_OBJECT(ppc->r_button),ppc);
 	gtk_signal_connect (GTK_OBJECT (ppc->r_button), "toggled", 
 			    GTK_SIGNAL_FUNC (corner_set_pos), 
@@ -549,7 +553,7 @@ corner_notebook_page(PerPanelConfig *ppc)
 			    CONFIG_PADDING_SIZE);
 
 	/* Hidebuttons frame */
-	frame = gtk_frame_new (_("Hidebutton Options"));
+	frame = gtk_frame_new (_("Hidebutton options"));
 	gtk_container_set_border_width(GTK_CONTAINER (frame), CONFIG_PADDING_SIZE);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
@@ -560,24 +564,29 @@ corner_notebook_page(PerPanelConfig *ppc)
 	gtk_container_add (GTK_CONTAINER (frame), box);
 	
 
-	/* Hidebuttons disable */
-	button = gtk_check_button_new_with_label (_("Disable hidebuttons"));
+	/* Hidebuttons enable */
+	w = button = gtk_check_button_new_with_label (_("Enable hidebuttons"));
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (!ppc->corner_hidebuttons)
+	if (ppc->corner_hidebuttons)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
-			    GTK_SIGNAL_FUNC (set_toggle_not),
+			    GTK_SIGNAL_FUNC (set_toggle),
 			    &ppc->corner_hidebuttons);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
-	/* Arrow disable */
-	button = gtk_check_button_new_with_label (_("Disable hidebutton arrows"));
+	/* Arrow enable */
+	button = gtk_check_button_new_with_label (_("Enable hidebutton arrows"));
+	gtk_signal_connect (GTK_OBJECT (w), "toggled", 
+			    GTK_SIGNAL_FUNC (set_sensitive_toggle),
+			    button);
+	if (!ppc->corner_hidebuttons)
+		gtk_widget_set_sensitive(button,FALSE);
 	gtk_object_set_user_data(GTK_OBJECT(button),ppc);
-	if (!ppc->corner_hidebutton_pixmaps)
+	if (ppc->corner_hidebutton_pixmaps)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
-			    GTK_SIGNAL_FUNC (set_toggle_not),
+			    GTK_SIGNAL_FUNC (set_toggle),
 			    &ppc->corner_hidebutton_pixmaps);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
@@ -865,13 +874,13 @@ panel_config(GtkWidget *panel)
 		page = snapped_notebook_page (ppc);
 		gtk_notebook_append_page (GTK_NOTEBOOK(prop_nbook),
 					  page,
-					  gtk_label_new (_("Edge Panel")));
+					  gtk_label_new (_("Edge panel")));
 	} else if(IS_CORNER_WIDGET(panel)) {
 		/* Corner notebook page */
 		page = corner_notebook_page (ppc);
 		gtk_notebook_append_page (GTK_NOTEBOOK(prop_nbook),
 					  page,
-					  gtk_label_new (_("Corner Panel")));
+					  gtk_label_new (_("Corner panel")));
 	} else if(IS_DRAWER_WIDGET(panel)) {
 		DrawerWidget *dw = DRAWER_WIDGET(panel);
 		GtkWidget *applet = PANEL_WIDGET(dw->panel)->master_widget;
