@@ -17,12 +17,10 @@ GlobalConfig temp_config;
 extern GlobalConfig global_config;
 extern int config_sync_timeout;
 extern int panels_to_sync;
-extern GList *applets_to_sync;
+extern GSList *applets_to_sync;
 extern int globals_to_sync;
 extern int need_complete_save;
 
-extern GList *panels;
-
 static GtkWidget *aniframe[3];
 
 static GtkWidget *tilefile[LAST_TILE];
@@ -33,11 +31,10 @@ static GtkWidget *entry_down[LAST_TILE];
 
 static GtkWidget *config_window;
 
-static int
+static void
 config_destroy(GtkWidget *widget, gpointer data)
 {
 	config_window = NULL;
-	return FALSE;
 }
 
 static void 
@@ -169,11 +166,11 @@ static int
 set_anim_button_value(GtkWidget *w, gpointer data)
 {
 	int i;
-	int active = GTK_TOGGLE_BUTTON(w)->active;
+	int disable = !(GTK_TOGGLE_BUTTON(w)->active);
 
 	for(i=0;i<3;i++)
-		gtk_widget_set_sensitive(aniframe[i],!active);
-	temp_config.disable_animations = active;
+		gtk_widget_set_sensitive(aniframe[i],!disable);
+	temp_config.disable_animations = disable;
 
 	if(config_window)
 		gnome_property_box_changed (GNOME_PROPERTY_BOX (config_window));
@@ -191,8 +188,8 @@ animation_notebook_page(void)
 	vbox = gtk_vbox_new (FALSE, CONFIG_PADDING_SIZE);
 	gtk_container_set_border_width(GTK_CONTAINER (vbox), CONFIG_PADDING_SIZE);
 
-	/* Animation disable */
-	button = gtk_check_button_new_with_label (_("Disable animations"));
+	/* Animation enable */
+	button = gtk_check_button_new_with_label (_("Enable animations"));
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
 			    GTK_SIGNAL_FUNC (set_anim_button_value),NULL); 
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE,
@@ -200,48 +197,54 @@ animation_notebook_page(void)
 
 
 	/* AutoHide Animation step_size scale frame */
-	frame = make_int_scale_frame(_("Auto-Hide Animation Speed"),
+	frame = make_int_scale_frame(_("Auto-hide animation speed"),
 				      &(temp_config.auto_hide_step_size),
 				      1.0, 100.0, 1.0);
+	if (temp_config.disable_animations)
+		gtk_widget_set_sensitive(frame,FALSE);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
 	aniframe[0] = frame;
 
 	/* ExplicitHide Animation step_size scale frame */
-	frame = make_int_scale_frame(_("Explicit-Hide Animation Speed"),
+	frame = make_int_scale_frame(_("Explicit-hide animation speed"),
 				      &(temp_config.explicit_hide_step_size),
 				      1.0, 100.0, 1.0);
+	if (temp_config.disable_animations)
+		gtk_widget_set_sensitive(frame,FALSE);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
 	aniframe[1] = frame;
 
 	/* DrawerHide Animation step_size scale frame */
-	frame = make_int_scale_frame(_("Drawer Animation Speed"),
+	frame = make_int_scale_frame(_("Drawer animation speed"),
 				      &(temp_config.drawer_step_size),
 				      1.0, 100.0, 1.0);
+	if (temp_config.disable_animations)
+		gtk_widget_set_sensitive(frame,FALSE);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
 	aniframe[2] = frame;
 
 	/* Minimize Delay scale frame */
-	frame = make_int_scale_frame(_("Auto-Hide Minimize Delay (ms)"),
+	frame = make_int_scale_frame(_("Auto-hide minimize delay (ms)"),
 				      &(temp_config.minimize_delay),
 				      30.0, 10000.0, 10.0);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
 	/* Minimized size scale frame */
-	frame = make_int_scale_frame(_("Auto-Hide Minimized Size (pixels)"),
+	frame = make_int_scale_frame(_("Auto-hide minimized size (pixels)"),
 				      &(temp_config.minimized_size),
 				      1.0, 10.0, 1.0);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
 	/*we have to do this after everything we need aniframe varaibles set*/
-	if (temp_config.disable_animations)
+	if (!temp_config.disable_animations)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 
 	return (vbox);
@@ -277,41 +280,43 @@ set_icon_button_value(GtkWidget *w, gpointer data)
 	return FALSE;
 }
 
-//static GtkWidget *
-//genicon_notebook_page(void)
-//{
-//	  GtkWidget *frame;
-//	  GtkWidget *w;
-//	  GtkWidget *box;
-//	  GtkWidget *vbox;
-//	  
-//	  /* main vbox */
-//	  vbox = gtk_vbox_new (FALSE, CONFIG_PADDING_SIZE);
-//	  gtk_container_set_border_width(GTK_CONTAINER (vbox), CONFIG_PADDING_SIZE);
-//	  
-//	  /* General frame */
-//	  frame = gtk_frame_new (_("General"));
-//	  gtk_container_set_border_width(GTK_CONTAINER (frame), CONFIG_PADDING_SIZE);
-//	  gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE,
-//			      CONFIG_PADDING_SIZE);
-//	  
-//	  /* vbox for frame */
-//	  box = gtk_vbox_new (FALSE, CONFIG_PADDING_SIZE);
-//	  gtk_container_set_border_width(GTK_CONTAINER (box), CONFIG_PADDING_SIZE);
-//	  gtk_container_add (GTK_CONTAINER (frame), box);
-//	  
-//	  /* Enable tiles frame */
-//	  w = gtk_check_button_new_with_label (_("Tiles enabled"));
-//	  if (temp_config.tiles_enabled[0])
-//		  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (w), TRUE);
-//	  gtk_signal_connect (GTK_OBJECT (w), "toggled", 
-//			      GTK_SIGNAL_FUNC (set_icon_button_value), 
-//			      &(temp_config.tiles_enabled[0]));
-//	  gtk_box_pack_start (GTK_BOX (box), w, FALSE, FALSE,
-//			      CONFIG_PADDING_SIZE);
-//
-//	  return (vbox);
-//}
+#if 0
+static GtkWidget *
+genicon_notebook_page(void)
+{
+	  GtkWidget *frame;
+	  GtkWidget *w;
+	  GtkWidget *box;
+	  GtkWidget *vbox;
+	  
+	  /* main vbox */
+	  vbox = gtk_vbox_new (FALSE, CONFIG_PADDING_SIZE);
+	  gtk_container_set_border_width(GTK_CONTAINER (vbox), CONFIG_PADDING_SIZE);
+	  
+	  /* General frame */
+	  frame = gtk_frame_new (_("General"));
+	  gtk_container_set_border_width(GTK_CONTAINER (frame), CONFIG_PADDING_SIZE);
+	  gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE,
+			      CONFIG_PADDING_SIZE);
+	  
+	  /* vbox for frame */
+	  box = gtk_vbox_new (FALSE, CONFIG_PADDING_SIZE);
+	  gtk_container_set_border_width(GTK_CONTAINER (box), CONFIG_PADDING_SIZE);
+	  gtk_container_add (GTK_CONTAINER (frame), box);
+	  
+	  /* Enable tiles frame */
+	  w = gtk_check_button_new_with_label (_("Tiles enabled"));
+	  if (temp_config.tiles_enabled[0])
+		  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (w), TRUE);
+	  gtk_signal_connect (GTK_OBJECT (w), "toggled", 
+			      GTK_SIGNAL_FUNC (set_icon_button_value), 
+			      &(temp_config.tiles_enabled[0]));
+	  gtk_box_pack_start (GTK_BOX (box), w, FALSE, FALSE,
+			      CONFIG_PADDING_SIZE);
+
+	  return (vbox);
+}
+#endif
 
 
 static GtkWidget *
@@ -477,7 +482,7 @@ misc_notebook_page(void)
 			    CONFIG_PADDING_SIZE);	
 	
 	/* Logout frame */
-	frame = gtk_frame_new (_("Log Out"));
+	frame = gtk_frame_new (_("Log out"));
 	gtk_container_set_border_width(GTK_CONTAINER (frame), CONFIG_PADDING_SIZE);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE,
 			    CONFIG_PADDING_SIZE);
@@ -498,7 +503,7 @@ misc_notebook_page(void)
 			    CONFIG_PADDING_SIZE);
 
 	/* Minimize Delay scale frame */
-	frame = make_int_scale_frame(_("Applet Padding"),
+	frame = make_int_scale_frame(_("Applet padding"),
 				      &(temp_config.applet_padding),
 				      0.0, 10.0, 1.0);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE,
@@ -534,10 +539,8 @@ panel_config_global(void)
 	gtk_window_set_policy(GTK_WINDOW(box), FALSE, FALSE, TRUE);
 	gtk_signal_connect(GTK_OBJECT(box), "destroy",
 			   GTK_SIGNAL_FUNC (config_destroy), NULL);
-	gtk_signal_connect (GTK_OBJECT (box), "delete_event",
-			    GTK_SIGNAL_FUNC (config_destroy), NULL);
 	gtk_window_set_title (GTK_WINDOW(box),
-			      _("Global Panel Configuration"));
+			      _("Global panel configuration"));
 	gtk_container_set_border_width (GTK_CONTAINER(box), CONFIG_PADDING_SIZE);
 	
 	prop_nbook = GNOME_PROPERTY_BOX (box)->notebook;
@@ -547,11 +550,13 @@ panel_config_global(void)
 	gtk_notebook_append_page (GTK_NOTEBOOK(prop_nbook),
 				  page, gtk_label_new (_("Animation")));
 
-//	  /* General icon notebook page */
-//	  page = genicon_notebook_page ();
-//	  gtk_notebook_append_page (GTK_NOTEBOOK(prop_nbook),
-//				    page, gtk_label_new (_("General icon settings")));
-//
+#if 0
+	  /* General icon notebook page */
+	  page = genicon_notebook_page ();
+	  gtk_notebook_append_page (GTK_NOTEBOOK(prop_nbook),
+				    page, gtk_label_new (_("General icon settings")));
+
+#endif
 	/* Specific icon notebook pages */
 	for(i = 0; i<LAST_TILE; i++) {
 		page = icon_notebook_page (i,box);
