@@ -89,54 +89,6 @@ marshal_signal_int (GtkObject * object,
 		  func_data);
 }
 
-static void
-set_frame_colors(SnappedWidget *snapped)
-{
-	if(PANEL_WIDGET(snapped->panel)->back_type == PANEL_BACK_COLOR) {
-		GdkColor n;
-		GtkStyle *ns;
-
-		ns = gtk_style_copy(snapped->panel->style);
-		gtk_style_ref(ns);
-
-		ns->bg[GTK_STATE_NORMAL] =
-			PANEL_WIDGET(snapped->panel)->back_color;
-		ns->base[GTK_STATE_NORMAL] =
-			PANEL_WIDGET(snapped->panel)->back_color;
-
-		n = PANEL_WIDGET(snapped->panel)->back_color;
-		n.red/=3;
-		n.green/=3;
-		n.blue/=3;
-		ns->dark[GTK_STATE_NORMAL] = n;
-
-		n = PANEL_WIDGET(snapped->panel)->back_color;
-		n.red/=2;
-		n.green/=2;
-		n.blue/=2;
-		ns->mid[GTK_STATE_NORMAL] = n;
-
-		n = PANEL_WIDGET(snapped->panel)->back_color;
-		n.red=MIN(65535,n.red*2);
-		n.green=MIN(65535,n.green*2);
-		n.blue=MIN(65535,n.blue*2);
-		ns->light[GTK_STATE_NORMAL] = n;
-
-		gtk_widget_set_style(snapped->frame, ns);
-
-		gtk_style_unref(ns);
-	} else {
-		GtkStyle *ns;
-
-		ns = gtk_rc_get_style(snapped->frame);
-		if(!ns) ns = gtk_style_new();
-
-		gtk_style_ref(ns);
-		gtk_widget_set_style(snapped->frame, ns);
-		gtk_style_unref(ns);
-	}
-}
-
 static void
 snapped_widget_realize(GtkWidget *w)
 {
@@ -156,7 +108,12 @@ snapped_widget_realize(GtkWidget *w)
 		gnome_win_hints_set_expanded_size(w, 0, 0, 0, 0);
 		gdk_window_set_decorations(w->window, 0);
 	}    
-	set_frame_colors(snapped);
+	set_frame_colors(PANEL_WIDGET(snapped->panel),
+			 snapped->frame,
+			 snapped->hidebutton_n,
+			 snapped->hidebutton_e,
+			 snapped->hidebutton_w,
+			 snapped->hidebutton_s);
 }
 
 static void
@@ -802,12 +759,6 @@ snapped_widget_show_hidebutton_pixmaps(SnappedWidget *snapped)
 	show_hidebutton_pixmap(snapped->hidebutton_s, show);
 }
 
-static int
-snapped_widget_destroy(GtkWidget *w, gpointer data)
-{
-	return FALSE;
-}
-
 static void
 snapped_widget_init (SnappedWidget *snapped)
 {
@@ -870,10 +821,6 @@ snapped_widget_init (SnappedWidget *snapped)
 	gtk_signal_connect(GTK_OBJECT(snapped), "leave_notify_event",
 			   GTK_SIGNAL_FUNC(snapped_leave_notify),
 			   NULL);
-	gtk_signal_connect(GTK_OBJECT(snapped),
-			   "destroy",
-			   GTK_SIGNAL_FUNC(snapped_widget_destroy),
-			   NULL);
 	snapped->pos = SNAPPED_BOTTOM;
 	snapped->mode = SNAPPED_EXPLICIT_HIDE;
 	snapped->state = SNAPPED_SHOWN;
@@ -892,7 +839,12 @@ s_back_change(PanelWidget *panel,
 	    GdkColor *color,
 	    SnappedWidget *snapped)
 {
-	set_frame_colors(snapped);
+	set_frame_colors(PANEL_WIDGET(snapped->panel),
+			 snapped->frame,
+			 snapped->hidebutton_n,
+			 snapped->hidebutton_e,
+			 snapped->hidebutton_w,
+			 snapped->hidebutton_s);
 }
 
 GtkWidget*
